'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DEFAULT_CONFIG = undefined;

var _babylon = require('babylon');

var _s2sUtils = require('s2s-utils');

var _flowFaker = require('flow-faker');

// import blog from 'babel-log'

const parseFromObj = obj => (0, _babylon.parseExpression)(JSON.stringify(obj), { plugins: ['flow'] });


const plugin = () => {
  return {
    inherits: _s2sUtils.inheritsOpts,
    name: 's2s-variable-initializing',
    visitor: {
      Program(programPath, state) {
        const { opts: { from } } = state;
        programPath.traverse({
          VariableDeclarator(nodePath) {
            if (nodePath.get('init').node) {
              return;
            }

            if (!nodePath.get('id.typeAnnotation').node) {
              return;
            }

            const { line, column } = nodePath.get('loc.start').node;

            const flowInfoObj = (0, _flowFaker.flowFakerSync)(from, {
              row: line,
              column: column + 1
            });

            nodePath.get('init').replaceWith(parseFromObj(flowInfoObj));
          }
        });
      }
    }
  };
};

const DEFAULT_CONFIG = exports.DEFAULT_CONFIG = {
  test: /.*.js$/,
  plugin
};

exports.default = plugin;